@@ -1,7 +1,7 @@
 /* Test file for mpfr_div_d
 
-Copyright 2007, 2008, 2009, 2010, 2011 Free Software Foundation, Inc.
-Contributed by the Arenaire and Cacao projects, INRIA.
+Copyright 2007-2015 Free Software Foundation, Inc.
+Contributed by the AriC and Caramel projects, INRIA.
 
 This file is part of the GNU MPFR Library.
 
@@ -64,18 +64,36 @@ check_nans (void)
   MPFR_ASSERTN (MPFR_IS_NEG (y));
 
   /* 0.0 / 0.0 is nan */
-  mpfr_set_d (x, 0.0, MPFR_RNDN);
+  mpfr_set_ui (x, 0, MPFR_RNDN);
   mpfr_clear_flags ();
   inexact = mpfr_div_d (y, x, 0.0, MPFR_RNDN);
   MPFR_ASSERTN (inexact == 0);
-  MPFR_ASSERTN ((__gmpfr_flags ^ MPFR_FLAGS_NAN) == 0);
+  MPFR_ASSERTN (__gmpfr_flags == MPFR_FLAGS_NAN);
   MPFR_ASSERTN (mpfr_nan_p (y));
 
+  /* 1.0 / 0.0 == +inf */
+  mpfr_set_ui (x, 1, MPFR_RNDN);
+  mpfr_clear_flags ();
+  inexact = mpfr_div_d (y, x, 0.0, MPFR_RNDN);
+  MPFR_ASSERTN (inexact == 0);
+  MPFR_ASSERTN (__gmpfr_flags == MPFR_FLAGS_DIVBY0);
+  MPFR_ASSERTN (mpfr_inf_p (y));
+  MPFR_ASSERTN (MPFR_IS_POS (y));
+
+  /* -1.0 / 0.0 == -inf */
+  mpfr_set_si (x, -1, MPFR_RNDN);
+  mpfr_clear_flags ();
+  inexact = mpfr_div_d (y, x, 0.0, MPFR_RNDN);
+  MPFR_ASSERTN (inexact == 0);
+  MPFR_ASSERTN (__gmpfr_flags == MPFR_FLAGS_DIVBY0);
+  MPFR_ASSERTN (mpfr_inf_p (y));
+  MPFR_ASSERTN (MPFR_IS_NEG (y));
+
   mpfr_clear (x);
   mpfr_clear (y);
 }
 
-#define TEST_FUNCTION mpfr_sub_d
+#define TEST_FUNCTION mpfr_div_d
 #define DOUBLE_ARG2
 #define RAND_FUNCTION(x) mpfr_random2(x, MPFR_LIMB_SIZE (x), 1, RANDS)
 #include "tgeneric.c"
