@@ -1,7 +1,9 @@
 /* tfprintf.c -- test file for mpfr_fprintf and mpfr_vfprintf
 
-Copyright 2008, 2009, 2010 Free Software Foundation, Inc.
-Contributed by the Arenaire and Cacao projects, INRIA.
+Copyright 2008-2015 Free Software Foundation, Inc.
+Contributed by the AriC and Caramel projects, INRIA.
+
+This file is part of the GNU MPFR Library.
 
 The GNU MPFR Library is free software; you can redistribute it and/or modify
 it under the terms of the GNU Lesser General Public License as published by
@@ -26,14 +28,7 @@ http://www.gnu.org/licenses/ or write to the Free Software Foundation, Inc.,
 #include <float.h>
 #include <stddef.h>
 
-#if HAVE_INTTYPES_H
-# include <inttypes.h> /* for intmax_t */
-#else
-# if HAVE_STDINT_H
-#  include <stdint.h>
-# endif
-#endif
-
+#include "mpfr-intmax.h"
 #include "mpfr-test.h"
 
 #if MPFR_VERSION >= MPFR_VERSION_NUM(2,4,0)
@@ -62,7 +57,7 @@ http://www.gnu.org/licenses/ or write to the Free Software Foundation, Inc.,
 const int prec_max_printf = 5000;
 
 static void
-check (FILE *fout, char *fmt, mpfr_t x)
+check (FILE *fout, const char *fmt, mpfr_t x)
 {
   if (mpfr_fprintf (fout, fmt, x) == -1)
     {
@@ -74,7 +69,7 @@ check (FILE *fout, char *fmt, mpfr_t x)
 }
 
 static void
-check_vfprintf (FILE *fout, char *fmt, ...)
+check_vfprintf (FILE *fout, const char *fmt, ...)
 {
   va_list ap;
 
@@ -141,8 +136,10 @@ static void
 check_mixed (FILE *fout)
 {
   int ch = 'a';
+#ifndef NPRINTF_HH
   signed char sch = -1;
   unsigned char uch = 1;
+#endif
   short sh = -1;
   unsigned short ush = 1;
   int i = -1;
@@ -152,9 +149,13 @@ check_mixed (FILE *fout)
   unsigned long ulo = 1;
   float f = -1.25;
   double d = -1.25;
+#if !defined(NPRINTF_T) || !defined(NPRINTF_L)
   long double ld = -1.25;
+#endif
 
+#ifndef NPRINTF_T
   ptrdiff_t p = 1, saved_p;
+#endif
   size_t sz = 1;
 
   mpz_t mpz;
@@ -212,8 +213,8 @@ check_mixed (FILE *fout)
 #endif
 
 #ifndef NPRINTF_HH
-  check_vfprintf (fout, "a. %hhi, b.%RA, c. %hhu%hhn", sch, mpfr, uch, &uch);
-  check_length (10, (unsigned int) uch, 21, u); /* no format specifier "%hhu" in C89 */
+  check_vfprintf (fout, "a. %hhi, b. %RA, c. %hhu%hhn", sch, mpfr, uch, &uch);
+  check_length (10, (unsigned int) uch, 22, u); /* no format specifier "%hhu" in C89 */
 #endif
 
 #if (__GNU_MP_VERSION * 10 + __GNU_MP_VERSION_MINOR) >= 42
@@ -310,7 +311,7 @@ check_random (FILE *fout, int nb_tests)
       char fmt[FMT_SIZE]; /* at most something like "%-+ #0'.*R*f" */
       char *ptr = fmt;
 
-      tests_default_random (x, 256, MPFR_EMIN_MIN, MPFR_EMAX_MAX);
+      tests_default_random (x, 256, MPFR_EMIN_MIN, MPFR_EMAX_MAX, 0);
       rnd = RND_RAND ();
 
       spec = (int) (randlimb () % 5);
@@ -438,7 +439,7 @@ int
 main (void)
 {
   /* We have nothing to test. */
-  return 0;
+  return 77;
 }
 
 #endif  /* HAVE_STDARG */
